@@ -196,23 +196,6 @@ spec:
       targetPort: 8443
   selector:
     k8s-app: kubernetes-dashboard
----
-# Grant admin privileges to the dashboard serviceacount
-
-apiVersion: rbac.authorization.k8s.io/v1beta1
-kind: ClusterRoleBinding
-metadata:
-  name: kubernetes-dashboard
-  labels:
-    k8s-app: kubernetes-dashboard
-roleRef:
-  apiGroup: rbac.authorization.k8s.io
-  kind: ClusterRole
-  name: cluster-admin
-subjects:
-- kind: ServiceAccount
-  name: kubernetes-dashboard
-  namespace: kube-system
 EOF
 }
 
@@ -352,8 +335,14 @@ spec:
 EOF
     }
 
+    if [ "$MASTER_INDEX" != "0" ]; then
+        exit 0
+    fi
+
+
+
     echo "Waiting for Kubernetes API..."
-    until curl --silent "http://127.0.0.1:8080/version"
+    until  [ "ok" = "$(curl --silent http://127.0.0.1:8080/healthz)" ]
     do
         sleep 5
     done
@@ -395,7 +384,7 @@ spec:
         imagePullPolicy: IfNotPresent
         command:
         - /heapster
-        - --source=kubernetes:https://kubernetes.default
+        - --source=kubernetes:https://kubernetes.default?insecure=false&useServiceAccount=true&kubeletPort=10250&kubeletHttps=true
 ${INFLUX_SINK}
 ---
 apiVersion: v1
@@ -425,14 +414,58 @@ roleRef:
   kind: ClusterRole
   name: system:heapster
 subjects:
+- kind: ServiceAccount
+  name: heapster
+  namespace: kube-system
+---
+apiVersion: rbac.authorization.k8s.io/v1beta1
+kind: ClusterRole
+metadata:
+  annotations:
+    rbac.authorization.kubernetes.io/autoupdate: "true"
+  labels:
+    kubernetes.io/bootstrapping: rbac-defaults
+  name: system:heapster-to-kubelet
+rules:
+  - apiGroups:
+      - ""
+    resources:
+      - nodes/proxy
+      - nodes/stats
+      - nodes/log
+      - nodes/spec
+      - nodes/metrics
+    verbs:
+      - "*"
+---
+apiVersion: rbac.authorization.k8s.io/v1beta1
+kind: ClusterRoleBinding
+metadata:
+  name: system:heapter-kubelet
+  namespace: kube-system
+roleRef:
+  apiGroup: rbac.authorization.k8s.io
+  kind: ClusterRole
+  name: system:heapster-to-kubelet
+subjects:
 - kind: ServiceAccount
   name: heapster
   namespace: kube-system
 EOF
 }
 
+# NOTE(flwang): Let's keep the same addons yaml file on all masters,
+# but if it's not the primary/bootstrapping master, don't try to
+# create those resources to avoid race condition issue until the
+# kubectl issue https://github.com/kubernetes/kubernetes/issues/44165
+# fixed.
+
+if [ "$MASTER_INDEX" != "0" ]; then
+    exit 0
+fi
+
 echo "Waiting for Kubernetes API..."
-until curl --silent "http://127.0.0.1:8080/version"
+until  [ "ok" = "$(curl --silent http://127.0.0.1:8080/healthz)" ]
 do
     sleep 5
 done
