@@ -255,10 +255,14 @@ class BaseTemplateDefinition(TemplateDefinition):
         else:
             extra_params['trust_id'] = ""
 
-        extra_params['auth_url'] = osc.url_for(
-            service_type='identity',
-            interface=CONF.trust.trustee_keystone_interface,
-            version=3)
+        kwargs = {
+            'service_type': 'identity',
+            'interface': CONF.trust.trustee_keystone_interface,
+            'version': 3
+        }
+        if CONF.trust.trustee_keystone_region_name:
+            kwargs['region_name'] = CONF.trust.trustee_keystone_region_name
+        extra_params['auth_url'] = osc.url_for(**kwargs)
 
         return super(BaseTemplateDefinition,
                      self).get_params(context, cluster_template, cluster,
@@ -313,7 +317,11 @@ class BaseTemplateDefinition(TemplateDefinition):
                 CONF.cluster.etcd_discovery_service_endpoint_format %
                 {'size': cluster.master_count})
             try:
-                discovery_url = requests.get(discovery_endpoint).text
+                discovery_request = requests.get(discovery_endpoint)
+                if discovery_request.status_code != requests.codes.ok:
+                    raise exception.GetDiscoveryUrlFailed(
+                        discovery_endpoint=discovery_endpoint)
+                discovery_url = discovery_request.text
             except req_exceptions.RequestException as err:
                 LOG.error(six.text_type(err))
                 raise exception.GetDiscoveryUrlFailed(
