@@ -135,16 +135,24 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
+    @patch('magnum.conductor.handlers.common.cert_manager'
+           '.sign_node_certificate')
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
     def test_extract_template_definition(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get):
         self._test_extract_template_definition(
+            mock_generate_csr_and_key, mock_sign_node_certificate,
             mock_driver, mock_objects_cluster_template_get_by_uuid, mock_get)
 
     def _test_extract_template_definition(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
@@ -155,12 +163,17 @@ class TestClusterConductorWithK8s(base.TestCase):
             self.cluster_dict[missing_attr] = None
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
+        mock_generate_csr_and_key.return_value = {'csr': 'csr',
+                                                  'private_key': 'private_key',
+                                                  'public_key': 'public_key'}
+        mock_sign_node_certificate.return_value = 'signed_cert'
         mock_objects_cluster_template_get_by_uuid.return_value = \
             cluster_template
         expected_result = str('{"action":"get","node":{"key":"test","value":'
                               '"1","modifiedIndex":10,"createdIndex":10}}')
         mock_resp = mock.MagicMock()
         mock_resp.text = expected_result
+        mock_resp.status_code = 200
         mock_get.return_value = mock_resp
         cluster = objects.Cluster(self.context, **self.cluster_dict)
         mock_driver.return_value = k8s_dr.Driver()
@@ -271,6 +284,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kubescheduler_options': '--kubescheduler',
             'kubeproxy_options': '--kubeproxy',
             'octavia_enabled': False,
+            'kube_service_account_key': 'public_key',
+            'kube_service_account_private_key': 'private_key',
         }
         if missing_attr is not None:
             expected.pop(mapping[missing_attr], None)
@@ -288,14 +303,23 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
+    @patch('magnum.conductor.handlers.common.cert_manager'
+           '.sign_node_certificate')
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
     def test_extract_template_definition_with_registry(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get):
         self.cluster_template_dict['registry_enabled'] = True
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
+        mock_generate_csr_and_key.return_value = {'csr': 'csr',
+                                                  'private_key': 'private_key',
+                                                  'public_key': 'public_key'}
+        mock_sign_node_certificate.return_value = 'signed_cert'
         mock_objects_cluster_template_get_by_uuid.return_value = \
             cluster_template
         expected_result = str('{"action":"get","node":{"key":"test","value":'
@@ -379,6 +403,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kubescheduler_options': '--kubescheduler',
             'kubeproxy_options': '--kubeproxy',
             'octavia_enabled': False,
+            'kube_service_account_key': 'public_key',
+            'kube_service_account_private_key': 'private_key',
         }
 
         self.assertEqual(expected, definition)
@@ -394,8 +420,13 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
+    @patch('magnum.conductor.handlers.common.cert_manager'
+           '.sign_node_certificate')
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
     def test_extract_template_definition_only_required(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get):
@@ -411,6 +442,10 @@ class TestClusterConductorWithK8s(base.TestCase):
 
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
+        mock_generate_csr_and_key.return_value = {'csr': 'csr',
+                                                  'private_key': 'private_key',
+                                                  'public_key': 'public_key'}
+        mock_sign_node_certificate.return_value = 'signed_cert'
         mock_objects_cluster_template_get_by_uuid.return_value = \
             cluster_template
         expected_result = str('{"action":"get","node":{"key":"test","value":'
@@ -474,6 +509,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kubescheduler_options': '--kubescheduler',
             'kubeproxy_options': '--kubeproxy',
             'octavia_enabled': False,
+            'kube_service_account_key': 'public_key',
+            'kube_service_account_private_key': 'private_key',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -502,6 +539,7 @@ class TestClusterConductorWithK8s(base.TestCase):
                               '"1","modifiedIndex":10,"createdIndex":10}}')
         mock_resp = mock.MagicMock()
         mock_resp.text = expected_result
+        mock_resp.status_code = 200
         mock_get.return_value = mock_resp
         cluster = objects.Cluster(self.context, **self.cluster_dict)
         mock_driver.return_value = k8s_coreos_dr.Driver()
@@ -580,7 +618,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             reqget):
         self.cluster_template_dict['cluster_distro'] = 'coreos'
         self.cluster_dict['discovery_url'] = None
-        mock_req = mock.MagicMock(text='http://tokentest/h1/h2/h3')
+        mock_req = mock.MagicMock(text='http://tokentest/h1/h2/h3',
+                                  status_code=200)
         reqget.return_value = mock_req
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
@@ -656,13 +695,20 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
+    @patch('magnum.conductor.handlers.common.cert_manager'
+           '.sign_node_certificate')
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
     def test_extract_template_definition_without_dns(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get):
         mock_driver.return_value = k8s_dr.Driver()
         self._test_extract_template_definition(
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
@@ -671,13 +717,20 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
+    @patch('magnum.conductor.handlers.common.cert_manager'
+           '.sign_node_certificate')
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
     def test_extract_template_definition_without_server_image(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get):
         mock_driver.return_value = k8s_dr.Driver()
         self._test_extract_template_definition(
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
@@ -686,13 +739,20 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
+    @patch('magnum.conductor.handlers.common.cert_manager'
+           '.sign_node_certificate')
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
     def test_extract_template_definition_without_docker_storage_driver(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get):
         mock_driver.return_value = k8s_dr.Driver()
         self._test_extract_template_definition(
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
@@ -701,13 +761,20 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
+    @patch('magnum.conductor.handlers.common.cert_manager'
+           '.sign_node_certificate')
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
     def test_extract_template_definition_without_apiserver_port(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get):
         mock_driver.return_value = k8s_dr.Driver()
         self._test_extract_template_definition(
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
@@ -716,13 +783,20 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
+    @patch('magnum.conductor.handlers.common.cert_manager'
+           '.sign_node_certificate')
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
     def test_extract_template_definition_without_node_count(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get):
         mock_driver.return_value = k8s_dr.Driver()
         self._test_extract_template_definition(
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
@@ -731,13 +805,20 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
+    @patch('magnum.conductor.handlers.common.cert_manager'
+           '.sign_node_certificate')
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
     def test_extract_template_definition_without_master_count(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get):
         mock_driver.return_value = k8s_dr.Driver()
         self._test_extract_template_definition(
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
@@ -746,13 +827,22 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
+    @patch('magnum.conductor.handlers.common.cert_manager'
+           '.sign_node_certificate')
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
     def test_extract_template_definition_without_discovery_url(
             self,
+            mock_generate_csr_and_key,
+            mock_sign_node_certificate,
             mock_driver,
             mock_objects_cluster_template_get_by_uuid,
             reqget):
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
+        mock_generate_csr_and_key.return_value = {'csr': 'csr',
+                                                  'private_key': 'private_key',
+                                                  'public_key': 'public_key'}
+        mock_sign_node_certificate.return_value = 'signed_cert'
         mock_objects_cluster_template_get_by_uuid.return_value = \
             cluster_template
         cluster_dict = self.cluster_dict
@@ -763,7 +853,8 @@ class TestClusterConductorWithK8s(base.TestCase):
         CONF.set_override('etcd_discovery_service_endpoint_format',
                           'http://etcd/test?size=%(size)d',
                           group='cluster')
-        mock_req = mock.MagicMock(text='https://address/token')
+        mock_req = mock.MagicMock(text='https://address/token',
+                                  status_code=200)
         reqget.return_value = mock_req
 
         (template_path,
@@ -829,6 +920,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kubescheduler_options': '--kubescheduler',
             'kubeproxy_options': '--kubeproxy',
             'octavia_enabled': False,
+            'kube_service_account_key': 'public_key',
+            'kube_service_account_private_key': 'private_key',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
