@@ -276,9 +276,18 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
                 '.get_params')
     @mock.patch('magnum.drivers.heat.template_def.TemplateDefinition'
                 '.get_output')
-    def test_k8s_get_params(self, mock_get_output, mock_get_params,
+    @mock.patch('magnum.conductor.handlers.common.cert_manager'
+                '.sign_node_certificate')
+    @mock.patch('magnum.common.x509.operations.generate_csr_and_key')
+    def test_k8s_get_params(self, mock_generate_csr_and_key,
+                            mock_sign_node_certificate,
+                            mock_get_output, mock_get_params,
                             mock_get_discovery_url, mock_osc_class,
                             mock_enable_octavia):
+        mock_generate_csr_and_key.return_value = {'csr': 'csr',
+                                                  'private_key': 'private_key',
+                                                  'public_key': 'public_key'}
+        mock_sign_node_certificate.return_value = 'signed_cert'
         mock_enable_octavia.return_value = False
         mock_context = mock.MagicMock()
         mock_context.auth_token = 'AUTH_TOKEN'
@@ -360,6 +369,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'kubescheduler_options')
         kubeproxy_options = mock_cluster.labels.get(
             'kubeproxy_options')
+        cloud_provider_enabled = mock_cluster.labels.get(
+            'cloud_provider_enabled')
 
         k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
 
@@ -387,6 +398,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'kubecontroller_options': kubecontroller_options,
             'kubescheduler_options': kubescheduler_options,
             'kubeproxy_options': kubeproxy_options,
+            'cloud_provider_enabled': cloud_provider_enabled,
             'username': 'fake_user',
             'magnum_url': mock_osc.magnum_url.return_value,
             'region_name': mock_osc.cinder_region_name.return_value,
@@ -406,12 +418,26 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'ingress_controller': ingress_controller,
             'ingress_controller_role': ingress_controller_role,
             'octavia_enabled': False,
+            'kube_service_account_key': 'public_key',
+            'kube_service_account_private_key': 'private_key',
         }}
         mock_get_params.assert_called_once_with(mock_context,
                                                 mock_cluster_template,
                                                 mock_cluster,
                                                 **expected_kwargs)
 
+        mock_cluster_template.volume_driver = 'cinder'
+        mock_cluster.labels = {'cloud_provider_enabled': 'false'}
+        k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
+        self.assertRaises(
+            exception.InvalidParameterValue,
+            k8s_def.get_params,
+            mock_context,
+            mock_cluster_template,
+            mock_cluster,
+            scale_manager=mock_scale_manager
+        )
+
     @mock.patch('magnum.common.keystone.is_octavia_enabled')
     @mock.patch('magnum.common.clients.OpenStackClients')
     @mock.patch('magnum.drivers.heat.template_def'
@@ -420,9 +446,18 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
                 '.get_params')
     @mock.patch('magnum.drivers.heat.template_def.TemplateDefinition'
                 '.get_output')
-    def test_k8s_get_params_insecure(self, mock_get_output, mock_get_params,
+    @mock.patch('magnum.conductor.handlers.common.cert_manager'
+                '.sign_node_certificate')
+    @mock.patch('magnum.common.x509.operations.generate_csr_and_key')
+    def test_k8s_get_params_insecure(self, mock_generate_csr_and_key,
+                                     mock_sign_node_certificate,
+                                     mock_get_output, mock_get_params,
                                      mock_get_discovery_url, mock_osc_class,
                                      mock_enable_octavia):
+        mock_generate_csr_and_key.return_value = {'csr': 'csr',
+                                                  'private_key': 'private_key',
+                                                  'public_key': 'public_key'}
+        mock_sign_node_certificate.return_value = 'signed_cert'
         mock_enable_octavia.return_value = False
         mock_context = mock.MagicMock()
         mock_context.auth_token = 'AUTH_TOKEN'
@@ -504,6 +539,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'kubescheduler_options')
         kubeproxy_options = mock_cluster.labels.get(
             'kubeproxy_options')
+        cloud_provider_enabled = mock_cluster.labels.get(
+            'cloud_provider_enabled')
 
         k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
 
@@ -531,6 +568,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'kubecontroller_options': kubecontroller_options,
             'kubescheduler_options': kubescheduler_options,
             'kubeproxy_options': kubeproxy_options,
+            'cloud_provider_enabled': cloud_provider_enabled,
             'username': 'fake_user',
             'magnum_url': mock_osc.magnum_url.return_value,
             'region_name': mock_osc.cinder_region_name.return_value,
@@ -552,6 +590,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'ingress_controller': ingress_controller,
             'ingress_controller_role': ingress_controller_role,
             'octavia_enabled': False,
+            'kube_service_account_key': 'public_key',
+            'kube_service_account_private_key': 'private_key',
         }}
         mock_get_params.assert_called_once_with(mock_context,
                                                 mock_cluster_template,
@@ -610,6 +650,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
         expected_discovery_url = 'http://etcd/token'
         mock_resp = mock.MagicMock()
         mock_resp.text = expected_discovery_url
+        mock_resp.status_code = 200
         mock_get.return_value = mock_resp
         mock_cluster = mock.MagicMock()
         mock_cluster.master_count = 10
@@ -647,6 +688,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
     def test_k8s_get_discovery_url_not_found(self, mock_get):
         mock_resp = mock.MagicMock()
         mock_resp.text = ''
+        mock_resp.status_code = 200
         mock_get.return_value = mock_resp
 
         fake_cluster = mock.MagicMock()
@@ -1182,6 +1224,7 @@ class AtomicSwarmTemplateDefinitionTestCase(base.TestCase):
         expected_discovery_url = 'http://etcd/token'
         mock_resp = mock.MagicMock()
         mock_resp.text = expected_discovery_url
+        mock_resp.status_code = 200
         mock_get.return_value = mock_resp
         mock_cluster = mock.MagicMock()
         mock_cluster.discovery_url = None
@@ -1197,6 +1240,7 @@ class AtomicSwarmTemplateDefinitionTestCase(base.TestCase):
     def test_swarm_get_discovery_url_not_found(self, mock_get):
         mock_resp = mock.MagicMock()
         mock_resp.text = ''
+        mock_resp.status_code = 200
         mock_get.return_value = mock_resp
 
         fake_cluster = mock.MagicMock()
